==> deepin-fcitx5configtool-plugin_6.0.11.tar.xz: BUILD/src/dcc-fcitx5configtool/translations/fcitx5configtool_kn_IN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>AddonsPage</name>
    <message>
        <location filename="../qml/AddonsPage.qml" line="20"/>
        <source>Add-ons</source>
        <translation>ಅಡ್ಡಾನ್ಸ್</translation>
    </message>
</context>
<context>
    <name>AdvancedSettingsModule</name>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="14"/>
        <source>Advanced Settings</source>
        <translation>ಅಧುನಿಕ ಸೆಟ್ಟಿಂಗ್ಸ್</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="40"/>
        <source>"Advanced Settings" is only valid for the input method that uses the system settings, if the input method has its own settings, its own settings shall prevail.</source>
        <translation>ಅಡ್ಡಾನ್ಸ್ ಸೆಟ್ಟಿಂಗ್ಸ್ ಅನ್ನು ಸಂಪೂರ್ಣ ಸೆಟ್ಟಿಂಗ್ಸ್ ಬಳಸುವ ಇನ್ಪುಟ್ ಮೆಥಡ್ಗೆ ಮಾತ್ರ ಅನ್ವಯಿಸುವುದು, ಇನ್ಪುಟ್ ಮೆಥಡ್ ತನ್ನದೇ ಸೆಟ್ಟಿಂಗ್ಸ್ ಅನ್ನು ಹೊಂದಿದ್ದರೆ, ಅದು ತನ್ನದೇ ಸೆಟ್ಟಿಂಗ್ಸ್ ಅನ್ನು ಅನ್ವಯಿಸುವುದು.</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="53"/>
        <source>Global Config</source>
        <translation>ಗ್ಲೋಬಲ್ ಕಂಫಿಗ್</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="69"/>
        <source>Add-ons</source>
        <translation>ಅಡ್ಡಾನ್ಸ್</translation>
    </message>
</context>
<context>
    <name>DetailConfigItem</name>
    <message>
        <location filename="../qml/DetailConfigItem.qml" line="150"/>
        <source>Please enter a new shortcut</source>
        <translation>ನೂತನ ಶರ್ಕ್ಯಟ್ ನಮ್ಮನ್ನು ಪ್ರವೇಶಿಸಿ</translation>
    </message>
</context>
<context>
    <name>IMList</name>
    <message>
        <location filename="../qml/IMList.qml" line="152"/>
        <source>Move Up</source>
        <translation>ಮೇಲೆ ಸರಿಯಿಸಿ</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="160"/>
        <source>Move Down</source>
        <translation>ಕೆಳಗೆ ಸರಿಯಿಸಿ</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="168"/>
        <source>Settings</source>
        <translation>ಸೆಟ್ಟಿಂಗ್ಸ್</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="176"/>
        <source>Remove</source>
        <translation>ಅপ್ರಾಪ್ತ</translation>
    </message>
</context>
<context>
    <name>InputMethodsChooser</name>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="35"/>
        <source>Add input method</source>
        <translation>ಇನ್ಪುಟ್ ಮೆಥಡ್ ಸೇರಿಸಿ</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="41"/>
        <source>Search</source>
        <translation>ಹುಡುಕಿ</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="109"/>
        <source>Find more in App Store</source>
        <translation>ಅಪ್ಪ್ ಸ್ಟೋರ್ನಲ್ಲಿ ಹೆಚ್ಚಿನವನ್ನು ಹುಡುಕಿ</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="129"/>
        <source>Cancel</source>
        <translation>ರದ್ದು</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="136"/>
        <source>Add</source>
        <translation>ಸೇರಿಸಿ</translation>
    </message>
</context>
<context>
    <name>ManageInputMethodsModule</name>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="15"/>
        <source>Input method management</source>
        <translation>ಇನ್ಪುಟ್ ಮೆಥಡ್ ಪರಿಪಾಲನೆ</translation>
    </message>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="33"/>
        <source>Add input method</source>
        <translation>ಇನ್ಪುಟ್ ಮೆಥಡ್ ಸೇರಿಸಿ</translation>
    </message>
</context>
<context>
    <name>ShortcutsModule</name>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="34"/>
        <source>Shortcuts</source>
        <translation>ಶರ್ಕ್ಯಟ್ಸ್</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="49"/>
        <source>Restore Defaults</source>
        <translation>ಪ್ರಮಾಣಿತ ಮೌಲ್ಯಗಳನ್ನು ಪುನರ್ಸ್ಥಾಪಿಸಿ</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="101"/>
        <source>Scroll between input methods</source>
        <translation>ಇನ್ಪುಟ್ ಮೆಥಡ್ಗಳ ನಡುವೆ ಸ್ಕ್ರೋಲ್ ಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="131"/>
        <source>Turn on or off input methods</source>
        <translation>ಇನ್ಪುಟ್ ಮೆಥಡ್ಗಳನ್ನು ಸಕ್ರಿಯಗೊಳಿಸಿ ಅಥವಾ ಬಂದು ಕೊಳ್ಳಿ</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="135"/>
        <source>Please enter a new shortcut</source>
        <translation>ನೂತನ ಶರ್ಕ್ಯಟ್ ನಮ್ಮನ್ನು ಪ್ರವೇಶಿಸಿ</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="162"/>
        <source>It turns on or off the currently used input method.If no input method is being used or the first input method is not the keyboard, it switches between the first input method and the currently used keyboard/input method.</source>
        <translation>ಇನ್ಪುಟ್ ಮೆಥಡ್ ಅನ್ನು ಸಕ್ರಿಯಗೊಳಿಸುವುದು ಅಥವಾ ಬಂದು ಕೊಳ್ಳುವುದು. ಇನ್ಪುಟ್ ಮೆಥಡ್ ಬಳಸಲಾಗಿಲ್ಲ ಅಥವಾ ಮೊದಲ ಇನ್ಪುಟ್ ಮೆಥಡ್ ಕೀಬೋರ್ಡ್ ಅಲ್ಲದಿದ್ದರೆ, ಅದು ಮೊದಲ ಇನ್ಪುಟ್ ಮೆಥಡ್ ಮತ್ತು ಇನ್ಪುಟ್ ಮೆಥಡ್ ಅನ್ನು ಬದಲಾಯಿಸುತ್ತದೆ.</translation>
    </message>
</context>
<context>
    <name>fcitx5configtool</name>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="8"/>
        <source>Input Methods</source>
        <translation>ಇನ್ಪುಟ್ ಮೆಥಡ್ಸ್</translation>
    </message>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="9"/>
        <source>Input method management, input method shortcuts, advanced settings</source>
        <translation>ಇನ್ಪುಟ್ ಮೆಥಡ್ ಪರಿಪಾಲನೆ, ಇನ್ಪುಟ್ ಮೆಥಡ್ ಶರ್ಕ್ಯಟ್ಸ್, ಅಧುನಿಕ ಸೆಟ್ಟಿಂಗ್ಸ್</translation>
    </message>
</context>
</TS>

==> deepin-fcitx5configtool-plugin_6.0.12.tar.xz: BUILD/src/dcc-fcitx5configtool/translations/fcitx5configtool_kn_IN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="kn_IN">
<context>
    <name>AddonsPage</name>
    <message>
        <location filename="../qml/AddonsPage.qml" line="20"/>
        <source>Add-ons</source>
        <translation>ಅಡ್ಡಾನ್ಸ್</translation>
    </message>
</context>
<context>
    <name>AdvancedSettingsModule</name>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="14"/>
        <source>Advanced Settings</source>
        <translation>ಅಧುನಿಕ ಸೆಟ್ಟಿಂಗ್ಸ್</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="28"/>
        <source>&quot;Advanced Settings&quot; is only valid for the input method that uses the system settings, if the input method has its own settings, its own settings shall prevail.</source>
        <translation>ಅಡ್ಡಾನ್ಸ್ ಸೆಟ್ಟಿಂಗ್ಸ್ ಅನ್ನು ಸಂಪೂರ್ಣ ಸೆಟ್ಟಿಂಗ್ಸ್ ಬಳಸುವ ಇನ್ಪುಟ್ ಮೆಥಡ್ಗೆ ಮಾತ್ರ ಅನ್ವಯಿಸುವುದು, ಇನ್ಪುಟ್ ಮೆಥಡ್ ತನ್ನದೇ ಸೆಟ್ಟಿಂಗ್ಸ್ ಅನ್ನು ಹೊಂದಿದ್ದರೆ, ಅದು ತನ್ನದೇ ಸೆಟ್ಟಿಂಗ್ಸ್ ಅನ್ನು ಅನ್ವಯಿಸುವುದು.</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="41"/>
        <source>Global Config</source>
        <translation>ಗ್ಲೋಬಲ್ ಕಂಫಿಗ್</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="52"/>
        <source>Add-ons</source>
        <translation>ಅಡ್ಡಾನ್ಸ್</translation>
    </message>
</context>
<context>
    <name>DetailConfigItem</name>
    <message>
        <location filename="../qml/DetailConfigItem.qml" line="126"/>
        <source>Please enter a new shortcut</source>
        <translation>ನೂತನ ಶರ್ಕ್ಯಟ್ ನಮ್ಮನ್ನು ಪ್ರವೇಶಿಸಿ</translation>
    </message>
</context>
<context>
    <name>IMList</name>
    <message>
        <location filename="../qml/IMList.qml" line="54"/>
        <source>Move Up</source>
        <translation>ಮೇಲೆ ಸರಿಯಿಸಿ</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="61"/>
        <source>Move Down</source>
        <translation>ಕೆಳಗೆ ಸರಿಯಿಸಿ</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="69"/>
        <source>Settings</source>
        <translation>ಸೆಟ್ಟಿಂಗ್ಸ್</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="76"/>
        <source>Remove</source>
        <translation>ಅপ್ರಾಪ್ತ</translation>
    </message>
</context>
<context>
    <name>InputMethodsChooser</name>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="29"/>
        <source>Add input method</source>
        <translation>ಇನ್ಪುಟ್ ಮೆಥಡ್ ಸೇರಿಸಿ</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="37"/>
        <source>Search</source>
        <translation>ಹುಡುಕಿ</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="102"/>
        <source>Find more in App Store</source>
        <translation>ಅಪ್ಪ್ ಸ್ಟೋರ್ನಲ್ಲಿ ಹೆಚ್ಚಿನವನ್ನು ಹುಡುಕಿ</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="121"/>
        <source>Cancel</source>
        <translation>ರದ್ದು</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="128"/>
        <source>Add</source>
        <translation>ಸೇರಿಸಿ</translation>
    </message>
</context>
<context>
    <name>ManageInputMethodsModule</name>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="15"/>
        <source>Input method management</source>
        <translation>ಇನ್ಪುಟ್ ಮೆಥಡ್ ಪರಿಪಾಲನೆ</translation>
    </message>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="29"/>
        <source>Add input method</source>
        <translation>ಇನ್ಪುಟ್ ಮೆಥಡ್ ಸೇರಿಸಿ</translation>
    </message>
</context>
<context>
    <name>ShortcutsModule</name>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="34"/>
        <source>Shortcuts</source>
        <translation>ಶರ್ಕ್ಯಟ್ಸ್</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="45"/>
        <source>Restore Defaults</source>
        <translation>ಪ್ರಮಾಣಿತ ಮೌಲ್ಯಗಳನ್ನು ಪುನರ್ಸ್ಥಾಪಿಸಿ</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="97"/>
        <source>Scroll between input methods</source>
        <translation>ಇನ್ಪುಟ್ ಮೆಥಡ್ಗಳ ನಡುವೆ ಸ್ಕ್ರೋಲ್ ಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="127"/>
        <source>Turn on or off input methods</source>
        <translation>ಇನ್ಪುಟ್ ಮೆಥಡ್ಗಳನ್ನು ಸಕ್ರಿಯಗೊಳಿಸಿ ಅಥವಾ ಬಂದು ಕೊಳ್ಳಿ</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="131"/>
        <source>Please enter a new shortcut</source>
        <translation>ನೂತನ ಶರ್ಕ್ಯಟ್ ನಮ್ಮನ್ನು ಪ್ರವೇಶಿಸಿ</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="156"/>
        <source>It turns on or off the currently used input method.If no input method is being used or the first input method is not the keyboard, it switches between the first input method and the currently used keyboard/input method.</source>
        <translation>ಇನ್ಪುಟ್ ಮೆಥಡ್ ಅನ್ನು ಸಕ್ರಿಯಗೊಳಿಸುವುದು ಅಥವಾ ಬಂದು ಕೊಳ್ಳುವುದು. ಇನ್ಪುಟ್ ಮೆಥಡ್ ಬಳಸಲಾಗಿಲ್ಲ ಅಥವಾ ಮೊದಲ ಇನ್ಪುಟ್ ಮೆಥಡ್ ಕೀಬೋರ್ಡ್ ಅಲ್ಲದಿದ್ದರೆ, ಅದು ಮೊದಲ ಇನ್ಪುಟ್ ಮೆಥಡ್ ಮತ್ತು ಇನ್ಪುಟ್ ಮೆಥಡ್ ಅನ್ನು ಬದಲಾಯಿಸುತ್ತದೆ.</translation>
    </message>
</context>
<context>
    <name>fcitx5configtool</name>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="8"/>
        <source>Input Methods</source>
        <translation>ಇನ್ಪುಟ್ ಮೆಥಡ್ಸ್</translation>
    </message>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="9"/>
        <source>Input method management, input method shortcuts, advanced settings</source>
        <translation>ಇನ್ಪುಟ್ ಮೆಥಡ್ ಪರಿಪಾಲನೆ, ಇನ್ಪುಟ್ ಮೆಥಡ್ ಶರ್ಕ್ಯಟ್ಸ್, ಅಧುನಿಕ ಸೆಟ್ಟಿಂಗ್ಸ್</translation>
    </message>
</context>
</TS>
